# eric7.Plugins.VcsPlugins.vcsGit.GitCommandDialog

Module implementing the Git command dialog.

### Global Attributes

None

### Classes

GitCommandDialog | Class implementing the Git command dialog.

### Functions

None

## GitCommandDialog

Class implementing the Git command dialog.

It implements a dialog that is used to enter an arbitrary Git command. It asks the user to enter the commandline parameters.

### Derived from

QDialog, Ui_GitCommandDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitCommandDialog | Constructor
getData | Public method to retrieve the data entered into this dialog.
on_commandCombo_editTextChanged | Private method used to enable/disable the OK-button.

### Static Methods

None

#### GitCommandDialog (Constructor)

GitCommandDialog(argvList, ppath, parent=None)

Constructor

argvList (list of str)
  history list of commandline arguments
ppath (str)
  pathname of the project directory
parent (QWidget)
  parent widget of this dialog

#### GitCommandDialog.getData

getData()

Public method to retrieve the data entered into this dialog.

Return:
  commandline parameters

Return Type:
  str

#### GitCommandDialog.on_commandCombo_editTextChanged

on_commandCombo_editTextChanged(_text)

Private method used to enable/disable the OK-button.

_text (str)
  text of the combobox (unused)

Up